boto v2.27.0 — boto v2.31.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.31.0 »

# boto v2.27.0

date: | 2014/03/06

This release adds support for configuring access logs on Elastic Load Balancing (including what Amazon Simple Storage Service (S3) bucket to use & how frequently logs should be added to the bucket), adds request hook documentation & a host of doc updates/bugfixes.

## Changes

- Added support for `AccessLog` in ELB (issue 2150, commit 7aa35ea)
- Added better BlockDeviceType deserialization in Autoscaling. (issue 2149, commit 04d29a5)
- Updated CloudFormation documentation (issue 2147, commit 2535aca)
- Updated Kinesis documentation (issue 2146, commit 01425dc)
- Add optional bucket tags to lss3 output. (issue 2132, commit 0f35924)
- Fix getting instance types for Eucalyptus 4.0. (issue 2118, commit 18dc07d)
- Fixed how quoted strings are handled in SigV4 (issue 2142, commit 2467547)
- Use system supplied certs without a bundle file (issue 2139, commit 70d15b8)
- Fixed incorrect test failures in EC2 `trim_snapshots` (commit 1fa9df7)
- Raise any exceptions that are tagSet not found (commit 56d7d3e)
- Added request hook docs (issue 2129, commit 64eedce)
- Fixed Route53 `alias-healthcheck` (issue 2126, commit 141077f)
- Fixed Elastic IP association in EC2 (issue 2131, issue 1310, commit d75fdfa)
- Fixed builds on Travis for installing dependencies (commit 5e84e30)
- Support printing tags on buckets when listing buckets (commit c42a5dd)
- PEP8/pyflakes/(some)pylint (commit 149175e)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.31.0 »